if select(6, GetAddOnInfo("PitBull4_" .. (debugstack():match("[o%.][d%.][u%.]les\\(.-)\\") or ""))) ~= "MISSING" then return end

local PitBull4 = _G.PitBull4
if not PitBull4 then
	error("PitBull4_PowerBarAlt requires PitBull4")
end

local EXAMPLE_VALUE = 0.6

local PitBull4_PowerBarAlt = PitBull4:NewModule("PowerBarAlt", "AceEvent-3.0")

PitBull4_PowerBarAlt:SetModuleType("bar")
PitBull4_PowerBarAlt:SetName("Alternate power bar")
PitBull4_PowerBarAlt:SetDescription("Show an \"alternate power\" bar for boss encounters.")
PitBull4_PowerBarAlt.allow_animations = true
PitBull4_PowerBarAlt:SetDefaults({
	hidepowerbaralt = false,
	position = 3,
})

local guids_to_update = {}

local timerFrame = CreateFrame("Frame")
timerFrame:Hide()
timerFrame:SetScript("OnUpdate", function()
	if next(guids_to_update) then
		for frame in PitBull4:IterateFrames() do
			if guids_to_update[frame.guid] then
				PitBull4_PowerBarAlt:Update(frame)
			end
		end
		wipe(guids_to_update)
	end
end)

function PitBull4_PowerBarAlt:OnEnable()
	self:RegisterEvent("UNIT_POWER")
	self:RegisterEvent("UNIT_MAXPOWER", "UNIT_POWER")
	self:RegisterEvent("UNIT_POWER_BAR_SHOW")
	self:RegisterEvent("UNIT_POWER_BAR_HIDE", "UNIT_POWER_BAR_SHOW")
	self:RegisterEvent("PLAYER_ENTERING_WORLD", "ShowHideBar")

	timerFrame:Show()
end

function PitBull4_PowerBarAlt:OnDisable()
	timerFrame:Hide()
end

function PitBull4_PowerBarAlt:GetValue(frame)
	local unit = frame.unit

	if UnitPowerMax(unit, ALTERNATE_POWER_INDEX) <= 0 then
		return nil
	end

	return UnitPower(unit, ALTERNATE_POWER_INDEX) / UnitPowerMax(unit, ALTERNATE_POWER_INDEX)
end

function PitBull4_PowerBarAlt:GetExampleValue()
	return EXAMPLE_VALUE
end

function PitBull4_PowerBarAlt:GetColor(frame, value)
	local color = PitBull4.PowerColors.POWER_TYPE_STEAM
	if color then
		return color[1], color[2], color[3]
	end
end

function PitBull4_PowerBarAlt:GetExampleColor()
	return unpack(PitBull4.PowerColors.POWER_TYPE_STEAM)
end

function PitBull4_PowerBarAlt:UNIT_POWER(event, unit, powerType)
	if powerType == "ALTERNATE" then
		guids_to_update[UnitGUID(unit)] = true
	end
end

function PitBull4_PowerBarAlt:UNIT_POWER_BAR_SHOW(event, unit)
	guids_to_update[UnitGUID(unit)] = true
	if unit == "player" then
		self:ShowHideBar()
	end
end

function PitBull4_PowerBarAlt:ShowHideBar()
	if self.db.profile.global.hidepowerbaralt then
		PlayerPowerBarAlt:Hide()
	elseif UnitAlternatePowerInfo("player") then
		PlayerPowerBarAlt:Show()
	end
end

PitBull4_PowerBarAlt:SetGlobalOptionsFunction(function(self)
	return 'hidepowerbaralt', {
		type = 'toggle',
		name = "Hide Blizzard frame",
		desc = "Hide the standard PlayerPowerBarAlt frame.",
		get = function(info)
			return self.db.profile.global.hidepowerbaralt
		end,
		set = function(info, value)
			self.db.profile.global.hidepowerbaralt = value
			self:ShowHideBar()
		end,
		hidden = function()
			return not self:IsEnabled()
		end,
	}
end)
